@@ -1,20 +1,40 @@
-'''Utilities for patching in cassettes'''
+"""Utilities for patching in cassettes"""
+import contextlib
 import functools
 import itertools
+from unittest import mock
 
-from .compat import contextlib, mock
 from .stubs import VCRHTTPConnection, VCRHTTPSConnection
-from six.moves import http_client as httplib
+import http.client as httplib
 
+import logging
 
+log = logging.getLogger(__name__)
 # Save some of the original types for the purposes of unpatching
 _HTTPConnection = httplib.HTTPConnection
 _HTTPSConnection = httplib.HTTPSConnection
 
-
-# Try to save the original types for requests
+# Try to save the original types for boto3
 try:
-    import requests.packages.urllib3.connectionpool as cpool
+    from botocore.awsrequest import AWSHTTPSConnection, AWSHTTPConnection
+except ImportError:
+    try:
+        import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+    except ImportError:  # pragma: no cover
+        pass
+    else:
+        _Boto3VerifiedHTTPSConnection = cpool.VerifiedHTTPSConnection
+        _cpoolBoto3HTTPConnection = cpool.HTTPConnection
+        _cpoolBoto3HTTPSConnection = cpool.HTTPSConnection
+else:
+    _Boto3VerifiedHTTPSConnection = AWSHTTPSConnection
+    _cpoolBoto3HTTPConnection = AWSHTTPConnection
+    _cpoolBoto3HTTPSConnection = AWSHTTPSConnection
+
+cpool = None
+# Try to save the original types for urllib3
+try:
+    import urllib3.connectionpool as cpool
 except ImportError:  # pragma: no cover
     pass
 else:
@@ -22,25 +42,16 @@ else:
     _cpoolHTTPConnection = cpool.HTTPConnection
     _cpoolHTTPSConnection = cpool.HTTPSConnection
 
-# Try to save the original types for boto3
+# Try to save the original types for requests
 try:
-    import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+    if not cpool:
+        import requests.packages.urllib3.connectionpool as cpool
 except ImportError:  # pragma: no cover
     pass
 else:
-    _Boto3VerifiedHTTPSConnection = cpool.VerifiedHTTPSConnection
-    _cpoolBoto3HTTPConnection = cpool.HTTPConnection
-    _cpoolBoto3HTTPSConnection = cpool.HTTPSConnection
-
-
-# Try to save the original types for urllib3
-try:
-    import urllib3
-except ImportError:  # pragma: no cover
-    pass
-else:
-    _VerifiedHTTPSConnection = urllib3.connectionpool.VerifiedHTTPSConnection
-
+    _VerifiedHTTPSConnection = cpool.VerifiedHTTPSConnection
+    _cpoolHTTPConnection = cpool.HTTPConnection
+    _cpoolHTTPSConnection = cpool.HTTPSConnection
 
 # Try to save the original types for httplib2
 try:
@@ -52,7 +63,6 @@ else:
     _HTTPSConnectionWithTimeout = httplib2.HTTPSConnectionWithTimeout
     _SCHEME_TO_CONNECTION = httplib2.SCHEME_TO_CONNECTION
 
-
 # Try to save the original types for boto
 try:
     import boto.https_connection
@@ -61,24 +71,20 @@ except ImportError:  # pragma: no cover
 else:
     _CertValidatingHTTPSConnection = boto.https_connection.CertValidatingHTTPSConnection
 
-
 # Try to save the original types for Tornado
 try:
     import tornado.simple_httpclient
 except ImportError:  # pragma: no cover
     pass
 else:
-    _SimpleAsyncHTTPClient_fetch_impl = \
-        tornado.simple_httpclient.SimpleAsyncHTTPClient.fetch_impl
-
+    _SimpleAsyncHTTPClient_fetch_impl = tornado.simple_httpclient.SimpleAsyncHTTPClient.fetch_impl
 
 try:
     import tornado.curl_httpclient
 except ImportError:  # pragma: no cover
     pass
 else:
-    _CurlAsyncHTTPClient_fetch_impl = \
-        tornado.curl_httpclient.CurlAsyncHTTPClient.fetch_impl
+    _CurlAsyncHTTPClient_fetch_impl = tornado.curl_httpclient.CurlAsyncHTTPClient.fetch_impl
 
 try:
     import aiohttp.client
@@ -88,14 +94,12 @@ else:
     _AiohttpClientSessionRequest = aiohttp.client.ClientSession._request
 
 
-class CassettePatcherBuilder(object):
-
+class CassettePatcherBuilder:
     def _build_patchers_from_mock_triples_decorator(function):
         @functools.wraps(function)
         def wrapped(self, *args, **kwargs):
-            return self._build_patchers_from_mock_triples(
-                function(self, *args, **kwargs)
-            )
+            return self._build_patchers_from_mock_triples(function(self, *args, **kwargs))
+
         return wrapped
 
     def __init__(self, cassette):
@@ -104,11 +108,15 @@ class CassettePatcherBuilder(object):
 
     def build(self):
         return itertools.chain(
-            self._httplib(), self._requests(), self._boto3(), self._urllib3(),
-            self._httplib2(), self._boto(), self._tornado(), self._aiohttp(),
-            self._build_patchers_from_mock_triples(
-                self._cassette.custom_patches
-            ),
+            self._httplib(),
+            self._requests(),
+            self._boto3(),
+            self._urllib3(),
+            self._httplib2(),
+            self._boto(),
+            self._tornado(),
+            self._aiohttp(),
+            self._build_patchers_from_mock_triples(self._cassette.custom_patches),
         )
 
     def _build_patchers_from_mock_triples(self, mock_triples):
@@ -121,9 +129,9 @@ class CassettePatcherBuilder(object):
         if not hasattr(obj, patched_attribute):
             return
 
-        return mock.patch.object(obj, patched_attribute,
-                                 self._recursively_apply_get_cassette_subclass(
-                                     replacement_class))
+        return mock.patch.object(
+            obj, patched_attribute, self._recursively_apply_get_cassette_subclass(replacement_class)
+        )
 
     def _recursively_apply_get_cassette_subclass(self, replacement_dict_or_obj):
         """One of the subtleties of this class is that it does not directly
@@ -145,13 +153,11 @@ class CassettePatcherBuilder(object):
         """
         if isinstance(replacement_dict_or_obj, dict):
             for key, replacement_obj in replacement_dict_or_obj.items():
-                replacement_obj = self._recursively_apply_get_cassette_subclass(
-                    replacement_obj)
+                replacement_obj = self._recursively_apply_get_cassette_subclass(replacement_obj)
                 replacement_dict_or_obj[key] = replacement_obj
             return replacement_dict_or_obj
-        if hasattr(replacement_dict_or_obj, 'cassette'):
-            replacement_dict_or_obj = self._get_cassette_subclass(
-                replacement_dict_or_obj)
+        if hasattr(replacement_dict_or_obj, "cassette"):
+            replacement_dict_or_obj = self._get_cassette_subclass(replacement_dict_or_obj)
         return replacement_dict_or_obj
 
     def _get_cassette_subclass(self, klass):
@@ -166,29 +172,44 @@ class CassettePatcherBuilder(object):
         bases = (base_class,)
         if not issubclass(base_class, object):  # Check for old style class
             bases += (object,)
-        return type('{0}{1}'.format(base_class.__name__, self._cassette._path),
-                    bases, dict(cassette=self._cassette))
+        return type(
+            "{}{}".format(base_class.__name__, self._cassette._path), bases, dict(cassette=self._cassette)
+        )
 
     @_build_patchers_from_mock_triples_decorator
     def _httplib(self):
-        yield httplib, 'HTTPConnection', VCRHTTPConnection
-        yield httplib, 'HTTPSConnection', VCRHTTPSConnection
+        yield httplib, "HTTPConnection", VCRHTTPConnection
+        yield httplib, "HTTPSConnection", VCRHTTPSConnection
 
     def _requests(self):
         try:
-            import requests.packages.urllib3.connectionpool as cpool
+            from .stubs import requests_stubs
         except ImportError:  # pragma: no cover
             return ()
-        from .stubs import requests_stubs
         return self._urllib3_patchers(cpool, requests_stubs)
 
+    @_build_patchers_from_mock_triples_decorator
     def _boto3(self):
+
         try:
-            import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+            # botocore using awsrequest
+            import botocore.awsrequest as cpool
         except ImportError:  # pragma: no cover
-            return ()
-        from .stubs import boto3_stubs
-        return self._urllib3_patchers(cpool, boto3_stubs)
+            try:
+                # botocore using vendored requests
+                import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+            except ImportError:  # pragma: no cover
+                pass
+            else:
+                from .stubs import boto3_stubs
+
+                yield self._urllib3_patchers(cpool, boto3_stubs)
+        else:
+            from .stubs import boto3_stubs
+
+            log.debug("Patching boto3 cpool with %s", cpool)
+            yield cpool.AWSHTTPConnectionPool, "ConnectionCls", boto3_stubs.VCRRequestsHTTPConnection
+            yield cpool.AWSHTTPSConnectionPool, "ConnectionCls", boto3_stubs.VCRRequestsHTTPSConnection
 
     def _patched_get_conn(self, connection_pool_class, connection_class_getter):
         get_conn = connection_pool_class._get_conn
@@ -197,8 +218,8 @@ class CassettePatcherBuilder(object):
         def patched_get_conn(pool, timeout=None):
             connection = get_conn(pool, timeout)
             connection_class = (
-                pool.ConnectionCls if hasattr(pool, 'ConnectionCls')
-                else connection_class_getter())
+                pool.ConnectionCls if hasattr(pool, "ConnectionCls") else connection_class_getter()
+            )
             # We need to make sure that we are actually providing a
             # patched version of the connection class. This might not
             # always be the case because the pool keeps previously
@@ -228,6 +249,7 @@ class CassettePatcherBuilder(object):
         except ImportError:  # pragma: no cover
             return ()
         from .stubs import urllib3_stubs
+
         return self._urllib3_patchers(cpool, urllib3_stubs)
 
     @_build_patchers_from_mock_triples_decorator
@@ -240,10 +262,12 @@ class CassettePatcherBuilder(object):
             from .stubs.httplib2_stubs import VCRHTTPConnectionWithTimeout
             from .stubs.httplib2_stubs import VCRHTTPSConnectionWithTimeout
 
-            yield cpool, 'HTTPConnectionWithTimeout', VCRHTTPConnectionWithTimeout
-            yield cpool, 'HTTPSConnectionWithTimeout', VCRHTTPSConnectionWithTimeout
-            yield cpool, 'SCHEME_TO_CONNECTION', {'http': VCRHTTPConnectionWithTimeout,
-                                                  'https': VCRHTTPSConnectionWithTimeout}
+            yield cpool, "HTTPConnectionWithTimeout", VCRHTTPConnectionWithTimeout
+            yield cpool, "HTTPSConnectionWithTimeout", VCRHTTPSConnectionWithTimeout
+            yield cpool, "SCHEME_TO_CONNECTION", {
+                "http": VCRHTTPConnectionWithTimeout,
+                "https": VCRHTTPSConnectionWithTimeout,
+            }
 
     @_build_patchers_from_mock_triples_decorator
     def _boto(self):
@@ -253,7 +277,8 @@ class CassettePatcherBuilder(object):
             pass
         else:
             from .stubs.boto_stubs import VCRCertValidatingHTTPSConnection
-            yield cpool, 'CertValidatingHTTPSConnection', VCRCertValidatingHTTPSConnection
+
+            yield cpool, "CertValidatingHTTPSConnection", VCRCertValidatingHTTPSConnection
 
     @_build_patchers_from_mock_triples_decorator
     def _tornado(self):
@@ -264,10 +289,8 @@ class CassettePatcherBuilder(object):
         else:
             from .stubs.tornado_stubs import vcr_fetch_impl
 
-            new_fetch_impl = vcr_fetch_impl(
-                self._cassette, _SimpleAsyncHTTPClient_fetch_impl
-            )
-            yield simple.SimpleAsyncHTTPClient, 'fetch_impl', new_fetch_impl
+            new_fetch_impl = vcr_fetch_impl(self._cassette, _SimpleAsyncHTTPClient_fetch_impl)
+            yield simple.SimpleAsyncHTTPClient, "fetch_impl", new_fetch_impl
         try:
             import tornado.curl_httpclient as curl
         except ImportError:  # pragma: no cover
@@ -275,10 +298,8 @@ class CassettePatcherBuilder(object):
         else:
             from .stubs.tornado_stubs import vcr_fetch_impl
 
-            new_fetch_impl = vcr_fetch_impl(
-                self._cassette, _CurlAsyncHTTPClient_fetch_impl
-            )
-            yield curl.CurlAsyncHTTPClient, 'fetch_impl', new_fetch_impl
+            new_fetch_impl = vcr_fetch_impl(self._cassette, _CurlAsyncHTTPClient_fetch_impl)
+            yield curl.CurlAsyncHTTPClient, "fetch_impl", new_fetch_impl
 
     @_build_patchers_from_mock_triples_decorator
     def _aiohttp(self):
@@ -288,10 +309,9 @@ class CassettePatcherBuilder(object):
             pass
         else:
             from .stubs.aiohttp_stubs import vcr_request
-            new_request = vcr_request(
-                self._cassette, _AiohttpClientSessionRequest
-            )
-            yield client.ClientSession, '_request', new_request
+
+            new_request = vcr_request(self._cassette, _AiohttpClientSessionRequest)
+            yield client.ClientSession, "_request", new_request
 
     def _urllib3_patchers(self, cpool, stubs):
         http_connection_remover = ConnectionRemover(
@@ -301,35 +321,45 @@ class CassettePatcherBuilder(object):
             self._get_cassette_subclass(stubs.VCRRequestsHTTPSConnection)
         )
         mock_triples = (
-            (cpool, 'VerifiedHTTPSConnection', stubs.VCRRequestsHTTPSConnection),
-            (cpool, 'VerifiedHTTPSConnection', stubs.VCRRequestsHTTPSConnection),
-            (cpool, 'HTTPConnection', stubs.VCRRequestsHTTPConnection),
-            (cpool, 'HTTPSConnection', stubs.VCRRequestsHTTPSConnection),
-            (cpool, 'is_connection_dropped', mock.Mock(return_value=False)),  # Needed on Windows only
-            (cpool.HTTPConnectionPool, 'ConnectionCls', stubs.VCRRequestsHTTPConnection),
-            (cpool.HTTPSConnectionPool, 'ConnectionCls', stubs.VCRRequestsHTTPSConnection),
+            (cpool, "VerifiedHTTPSConnection", stubs.VCRRequestsHTTPSConnection),
+            (cpool, "HTTPConnection", stubs.VCRRequestsHTTPConnection),
+            (cpool, "HTTPSConnection", stubs.VCRRequestsHTTPSConnection),
+            (cpool, "is_connection_dropped", mock.Mock(return_value=False)),  # Needed on Windows only
+            (cpool.HTTPConnectionPool, "ConnectionCls", stubs.VCRRequestsHTTPConnection),
+            (cpool.HTTPSConnectionPool, "ConnectionCls", stubs.VCRRequestsHTTPSConnection),
         )
         # These handle making sure that sessions only use the
         # connections of the appropriate type.
-        mock_triples += ((cpool.HTTPConnectionPool, '_get_conn',
-                          self._patched_get_conn(cpool.HTTPConnectionPool,
-                                                 lambda: cpool.HTTPConnection)),
-                         (cpool.HTTPSConnectionPool, '_get_conn',
-                          self._patched_get_conn(cpool.HTTPSConnectionPool,
-                                                 lambda: cpool.HTTPSConnection)),
-                         (cpool.HTTPConnectionPool, '_new_conn',
-                          self._patched_new_conn(cpool.HTTPConnectionPool,
-                                                 http_connection_remover)),
-                         (cpool.HTTPSConnectionPool, '_new_conn',
-                          self._patched_new_conn(cpool.HTTPSConnectionPool,
-                                                 https_connection_remover)))
+        mock_triples += (
+            (
+                cpool.HTTPConnectionPool,
+                "_get_conn",
+                self._patched_get_conn(cpool.HTTPConnectionPool, lambda: cpool.HTTPConnection),
+            ),
+            (
+                cpool.HTTPSConnectionPool,
+                "_get_conn",
+                self._patched_get_conn(cpool.HTTPSConnectionPool, lambda: cpool.HTTPSConnection),
+            ),
+            (
+                cpool.HTTPConnectionPool,
+                "_new_conn",
+                self._patched_new_conn(cpool.HTTPConnectionPool, http_connection_remover),
+            ),
+            (
+                cpool.HTTPSConnectionPool,
+                "_new_conn",
+                self._patched_new_conn(cpool.HTTPSConnectionPool, https_connection_remover),
+            ),
+        )
 
-        return itertools.chain(self._build_patchers_from_mock_triples(mock_triples),
-                               (http_connection_remover, https_connection_remover))
+        return itertools.chain(
+            self._build_patchers_from_mock_triples(mock_triples),
+            (http_connection_remover, https_connection_remover),
+        )
 
 
-class ConnectionRemover(object):
-
+class ConnectionRemover:
     def __init__(self, connection_class):
         self._connection_class = connection_class
         self._connection_pool_to_connections = {}
@@ -359,93 +389,109 @@ class ConnectionRemover(object):
 
 
 def reset_patchers():
-    yield mock.patch.object(httplib, 'HTTPConnection', _HTTPConnection)
-    yield mock.patch.object(httplib, 'HTTPSConnection', _HTTPSConnection)
+    yield mock.patch.object(httplib, "HTTPConnection", _HTTPConnection)
+    yield mock.patch.object(httplib, "HTTPSConnection", _HTTPSConnection)
+
     try:
-        import requests.packages.urllib3.connectionpool as cpool
+        import requests
+
+        if requests.__build__ < 0x021603:
+            # Avoid double unmock if requests 2.16.3
+            # First, this is pointless, requests.packages.urllib3 *IS* urllib3 (see packages.py)
+            # Second, this is unmocking twice the same classes with different namespaces
+            # and is creating weird issues and bugs:
+            # > AssertionError: assert <class 'urllib3.connection.HTTPConnection'>
+            # >   is <class 'requests.packages.urllib3.connection.HTTPConnection'>
+            # This assert should work!!!
+            # Note that this also means that now, requests.packages is never imported
+            # if requests 2.16.3 or greater is used with VCRPy.
+            import requests.packages.urllib3.connectionpool as cpool
+        else:
+            raise ImportError("Skip requests not vendored anymore")
     except ImportError:  # pragma: no cover
         pass
     else:
         # unpatch requests v1.x
-        yield mock.patch.object(cpool, 'VerifiedHTTPSConnection', _VerifiedHTTPSConnection)
-        yield mock.patch.object(cpool, 'HTTPConnection', _cpoolHTTPConnection)
+        yield mock.patch.object(cpool, "VerifiedHTTPSConnection", _VerifiedHTTPSConnection)
+        yield mock.patch.object(cpool, "HTTPConnection", _cpoolHTTPConnection)
         # unpatch requests v2.x
-        if hasattr(cpool.HTTPConnectionPool, 'ConnectionCls'):
-            yield mock.patch.object(cpool.HTTPConnectionPool, 'ConnectionCls',
-                                    _cpoolHTTPConnection)
-            yield mock.patch.object(cpool.HTTPSConnectionPool, 'ConnectionCls',
-                                    _cpoolHTTPSConnection)
+        if hasattr(cpool.HTTPConnectionPool, "ConnectionCls"):
+            yield mock.patch.object(cpool.HTTPConnectionPool, "ConnectionCls", _cpoolHTTPConnection)
+            yield mock.patch.object(cpool.HTTPSConnectionPool, "ConnectionCls", _cpoolHTTPSConnection)
 
-        if hasattr(cpool, 'HTTPSConnection'):
-            yield mock.patch.object(cpool, 'HTTPSConnection', _cpoolHTTPSConnection)
+        if hasattr(cpool, "HTTPSConnection"):
+            yield mock.patch.object(cpool, "HTTPSConnection", _cpoolHTTPSConnection)
 
     try:
         import urllib3.connectionpool as cpool
     except ImportError:  # pragma: no cover
         pass
     else:
-        yield mock.patch.object(cpool, 'VerifiedHTTPSConnection', _VerifiedHTTPSConnection)
-        yield mock.patch.object(cpool, 'HTTPConnection', _HTTPConnection)
-        yield mock.patch.object(cpool, 'HTTPSConnection', _HTTPSConnection)
-        if hasattr(cpool.HTTPConnectionPool, 'ConnectionCls'):
-            yield mock.patch.object(cpool.HTTPConnectionPool, 'ConnectionCls', _HTTPConnection)
-            yield mock.patch.object(cpool.HTTPSConnectionPool, 'ConnectionCls', _HTTPSConnection)
+        yield mock.patch.object(cpool, "VerifiedHTTPSConnection", _VerifiedHTTPSConnection)
+        yield mock.patch.object(cpool, "HTTPConnection", _cpoolHTTPConnection)
+        yield mock.patch.object(cpool, "HTTPSConnection", _cpoolHTTPSConnection)
+        if hasattr(cpool.HTTPConnectionPool, "ConnectionCls"):
+            yield mock.patch.object(cpool.HTTPConnectionPool, "ConnectionCls", _cpoolHTTPConnection)
+            yield mock.patch.object(cpool.HTTPSConnectionPool, "ConnectionCls", _cpoolHTTPSConnection)
 
     try:
-        import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+        # unpatch botocore with awsrequest
+        import botocore.awsrequest as cpool
     except ImportError:  # pragma: no cover
-        pass
-    else:
-        # unpatch requests v1.x
-        yield mock.patch.object(cpool, 'VerifiedHTTPSConnection', _Boto3VerifiedHTTPSConnection)
-        yield mock.patch.object(cpool, 'HTTPConnection', _cpoolBoto3HTTPConnection)
-        # unpatch requests v2.x
-        if hasattr(cpool.HTTPConnectionPool, 'ConnectionCls'):
-            yield mock.patch.object(cpool.HTTPConnectionPool, 'ConnectionCls',
-                                    _cpoolBoto3HTTPConnection)
-            yield mock.patch.object(cpool.HTTPSConnectionPool, 'ConnectionCls',
-                                    _cpoolBoto3HTTPSConnection)
+        try:
+            # unpatch botocore with vendored requests
+            import botocore.vendored.requests.packages.urllib3.connectionpool as cpool
+        except ImportError:  # pragma: no cover
+            pass
+        else:
+            # unpatch requests v1.x
+            yield mock.patch.object(cpool, "VerifiedHTTPSConnection", _Boto3VerifiedHTTPSConnection)
+            yield mock.patch.object(cpool, "HTTPConnection", _cpoolBoto3HTTPConnection)
+            # unpatch requests v2.x
+            if hasattr(cpool.HTTPConnectionPool, "ConnectionCls"):
+                yield mock.patch.object(cpool.HTTPConnectionPool, "ConnectionCls", _cpoolBoto3HTTPConnection)
+                yield mock.patch.object(
+                    cpool.HTTPSConnectionPool, "ConnectionCls", _cpoolBoto3HTTPSConnection
+                )
 
-        if hasattr(cpool, 'HTTPSConnection'):
-            yield mock.patch.object(cpool, 'HTTPSConnection', _cpoolBoto3HTTPSConnection)
+            if hasattr(cpool, "HTTPSConnection"):
+                yield mock.patch.object(cpool, "HTTPSConnection", _cpoolBoto3HTTPSConnection)
+    else:
+        if hasattr(cpool.AWSHTTPConnectionPool, "ConnectionCls"):
+            yield mock.patch.object(cpool.AWSHTTPConnectionPool, "ConnectionCls", _cpoolBoto3HTTPConnection)
+            yield mock.patch.object(cpool.AWSHTTPSConnectionPool, "ConnectionCls", _cpoolBoto3HTTPSConnection)
+
+        if hasattr(cpool, "AWSHTTPSConnection"):
+            yield mock.patch.object(cpool, "AWSHTTPSConnection", _cpoolBoto3HTTPSConnection)
 
     try:
         import httplib2 as cpool
     except ImportError:  # pragma: no cover
         pass
     else:
-        yield mock.patch.object(cpool, 'HTTPConnectionWithTimeout', _HTTPConnectionWithTimeout)
-        yield mock.patch.object(cpool, 'HTTPSConnectionWithTimeout', _HTTPSConnectionWithTimeout)
-        yield mock.patch.object(cpool, 'SCHEME_TO_CONNECTION', _SCHEME_TO_CONNECTION)
+        yield mock.patch.object(cpool, "HTTPConnectionWithTimeout", _HTTPConnectionWithTimeout)
+        yield mock.patch.object(cpool, "HTTPSConnectionWithTimeout", _HTTPSConnectionWithTimeout)
+        yield mock.patch.object(cpool, "SCHEME_TO_CONNECTION", _SCHEME_TO_CONNECTION)
 
     try:
         import boto.https_connection as cpool
     except ImportError:  # pragma: no cover
         pass
     else:
-        yield mock.patch.object(cpool, 'CertValidatingHTTPSConnection',
-                                _CertValidatingHTTPSConnection)
+        yield mock.patch.object(cpool, "CertValidatingHTTPSConnection", _CertValidatingHTTPSConnection)
 
     try:
         import tornado.simple_httpclient as simple
     except ImportError:  # pragma: no cover
         pass
     else:
-        yield mock.patch.object(
-            simple.SimpleAsyncHTTPClient,
-            'fetch_impl',
-            _SimpleAsyncHTTPClient_fetch_impl,
-        )
+        yield mock.patch.object(simple.SimpleAsyncHTTPClient, "fetch_impl", _SimpleAsyncHTTPClient_fetch_impl)
     try:
         import tornado.curl_httpclient as curl
     except ImportError:  # pragma: no cover
         pass
     else:
-        yield mock.patch.object(
-            curl.CurlAsyncHTTPClient,
-            'fetch_impl',
-            _CurlAsyncHTTPClient_fetch_impl,
-        )
+        yield mock.patch.object(curl.CurlAsyncHTTPClient, "fetch_impl", _CurlAsyncHTTPClient_fetch_impl)
 
 
 @contextlib.contextmanager
